<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>CrashReportDialog</name>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="70"/>
        <source>This file contains the internal state of the program when it crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="76"/>
        <source>Dump file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="104"/>
        <source>Sending ...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="135"/>
        <source>Unexpected response (code %1) from dispatcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="160"/>
        <source>Unexpected response from dispatcher</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="220"/>
        <source>Unexpected response (code %1) from the receiving side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/CrashReportDialog.cpp" line="226"/>
        <source>Successfully sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="14"/>
        <source>Crash Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="20"/>
        <source>Scan Tailor crashed.  That&apos;s usually caused by errors in the software.  You can help us find and fix the problem by submitting this crash report.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="30"/>
        <source>Information to be sent</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="63"/>
        <source>If you have additional information, for example you know how to reproduce the crash, please provide it here.
English or Russian please.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="71"/>
        <source>If you are willing to provide further assistance to developers to help fix this problem, please provide your email address.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../crash_reporter/ui/CrashReportDialog.ui" line="81"/>
        <source>Email [optional]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
